import type { Either, ErrorResolver } from '@lokalise/node-core';
import type { QueueConsumer, NewQueueOptions, ExistingQueueOptions, BarrierResult } from '@message-queue-toolkit/core';
import type { Connection, Message } from 'amqplib';
import type { AMQPConsumerDependencies, CreateAMQPQueueOptions } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPLocatorType = {
    queueName: string;
};
export type NewAMQPConsumerOptions = NewQueueOptions<CreateAMQPQueueOptions>;
export type ExistingAMQPConsumerOptions = ExistingQueueOptions<AMQPLocatorType>;
export declare abstract class AbstractAmqpBaseConsumer<MessagePayloadType extends object, BarrierOutput = undefined> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    protected readonly errorResolver: ErrorResolver;
    constructor(dependencies: AMQPConsumerDependencies, options: NewAMQPConsumerOptions | ExistingAMQPConsumerOptions);
    private internalProcessMessage;
    protected abstract preHandlerBarrier(message: MessagePayloadType, messageType: string): Promise<BarrierResult<BarrierOutput>>;
    abstract processMessage(message: MessagePayloadType, messageType: string, barrierOutput: BarrierOutput): Promise<Either<'retryLater', 'success'>>;
    private deserializeMessage;
    receiveNewConnection(connection: Connection): Promise<void>;
    private consume;
    start(): Promise<void>;
    protected resolveMessage(message: Message): Either<import("@message-queue-toolkit/core").MessageInvalidFormatError | import("@message-queue-toolkit/core").MessageValidationError, unknown>;
}
